@@ -11,10 +11,7 @@
 #define HAVE_SYS_MNTTAB_H 0
 #define HAVE_SYS_MOUNT_H 1
 
-#define HAVE_MNTENT_H 1
-
-#define   HAVE_GETMNTINFO 0
-#define   HAVE_SETMNTENT 1
+#define HAVE_GETMNTINFO 0
 
 #define HAVE_LIBMOUNT 1
 
